bayespy.inference.vmp.nodes.dirichlet.DirichletMoments.compute_dims_from_values
===============================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.dirichlet

.. automethod:: DirichletMoments.compute_dims_from_values